# Portal Tool
Assortment of tools for the Portal project

## Requirements
Make sure you have the following installed on your system:
- Python 3.12 or higher
- git
- cmake
- ninja (build system)
- C++ 23+ compiler (recommend clang 20+)